.. currentmodule:: odooly

=================
Developer's notes
=================


Source code
-----------

* `Source code <https://github.com/tinyerp/odooly>`_ and
  `issue tracker <https://github.com/tinyerp/odooly/issues>`_ on GitHub.
* Continuous tests with Python 3.7 through 3.14 and PyPy.


Third-party integration
-----------------------

This module can be used with other Python libraries to achieve more
complex tasks.

For example:

* write unit tests using the standard `unittest
  <https://docs.python.org/library/unittest.html>`_ framework.
* write BDD tests using the `Gherkin language <https://behave.readthedocs.io/
  en/latest/gherkin/#gherkin-feature-testing-language>`_, and a library
  like `Behave <https://behave.readthedocs.io/>`_.
* build an interface for Odoo, using a framework like
  `Flask <https://flask.palletsprojects.com/>`_ (HTML, JSON, SOAP, ...).



Changes
-------

.. include:: ../CHANGES.rst
   :start-line: 3
